import * as React from "react";
import { IDataBinder } from "./formCore";
import { FormBinder } from "./formBinders";
export interface IFormProps extends React.HTMLProps<Form> {
    /** The forms data binder instance, this contains the data that is used by bound form elements*/
    dataBinder: IDataBinder<any>;
    /** Called when bound form data changes: NOTE, this is called on every key stroke/interaction on any of the bound fields */
    onDataChanged?: (data?: any) => void;
    /** Called when bound form data changes: NOTE, this is called on every key stroke/interaction on any of the bound fields */
    onDataBinderChange?: (dataBinder: IDataBinder<any>) => void;
}
export interface IFormContext {
    dataBinder: IDataBinder<any>;
    parent: IFormContext;
}
/**
A stateless data bindable form - state is held within the 'dataBinder' property
NOTE: This is designed to render all elements in the form on every change. This allows other participating elements to react to these changes
NOTE: This element provides a react context, this can be used to get access to any parent (or parent's with nested forms) data binder
*/
export declare class Form extends React.Component<IFormProps, {}> {
    static contextTypes: {
        "form": React.Requireable<any>;
    };
    static getFormContext(context: any): IFormContext;
    getChildContext(): {
        form: IFormContext;
    };
    static childContextTypes: {
        form: React.Requireable<any>;
    };
    static Bind: typeof FormBinder;
    static jsonDataBinder<T>(data: T): IDataBinder<T>;
    static jsonDataBinderWithClone<T>(data: T): IDataBinder<T>;
    private preventDefault;
    render(): React.DOMElement<React.HTMLAttributes<HTMLDivElement>, HTMLDivElement> | React.DOMElement<React.HTMLAttributes<HTMLFormElement>, HTMLFormElement>;
    private processChildren(node);
    private notifyChange;
}
